##  How the Integration Works
Now that we have established some of the benefits of the out-of-the-box connector between Apptio and SAP LeanIX, let’s take a look at how the holistic link between business, IT, and finance works.
![1390](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274432237a441014a53c80de449036d6_LowRes.png)
Two Phases of the Apptio-SAP LeanIX Integration
